@@ -73,7 +73,7 @@ class Scraper:
                 el = self.join(el, join)
 
         # step 3 apply dataTypes
-        if '[' in dataType: # in the case dataType is a datetime with format (DATE[%Y-%m-%d %H:%M:%S])
+        if dataType is not None and '[' in dataType: # in the case dataType is a datetime with format (DATE[%Y-%m-%d %H:%M:%S])
             tokens = dataType.split('[')
             dataType = tokens[0]
             format = dataType[1][:-1]
